from enum import Enum

class EnergyDataInterval(str, Enum):
    """Energy data interval."""

    Hourly = "Hourly"
    """Hourly interval. `start_date` and `end_date` are an inclusive interval
    that must not be greater than 8 days.
    """

    Daily = "Daily"
    """Daily interval. `start_date` must be the first day of a quarter."""

    Monthly = "Monthly"
    """Monthly interval. `start_date` must be the first day of a year."""



from enum import Enum

class ChargingStatus(str, Enum):
    Finished = "finished"
    Normal = "normal"

class OvercurrentStatus(str, Enum):
    Lifted = "lifted"
    Normal = "normal"

class OverheatStatus(str, Enum):
    CoolDown = "cool_down"
    Normal = "normal"
    Overheated = "overheated"

class PowerProtectionStatus(str, Enum):
    Normal = "normal"
    Overloaded = "overloaded"



from enum import Enum

class DefaultBrightnessState:
    """Default brightness state."""

    type: DefaultStateType
    value: int

class DefaultStateType(str, Enum):
    """The type of the default state."""

    Custom = "custom"
    LastStates = "last_states"

class DefaultPowerType(str, Enum):
    """The type of the default power state."""

    AlwaysOn = "always_on"
    LastStates = "last_states"



from typing import Optional

from tapo.responses.device_info_result.default_state import DefaultStateType
from tapo.responses.device_info_result.power_status import (
    ChargingStatus,
    OvercurrentStatus,
    OverheatStatus,
    PowerProtectionStatus,
)

class DeviceInfoPlugEnergyMonitoringResult:
    """Device info of Tapo P110 and P115. Superset of `GenericDeviceInfoResult`."""

    device_id: str
    type: str
    model: str
    hw_id: str
    hw_ver: str
    fw_id: str
    fw_ver: str
    oem_id: str
    mac: str
    ip: str
    ssid: str
    signal_level: int
    rssi: int
    specs: str
    lang: str
    device_on: bool
    on_time: int
    """The time in seconds this device has been ON since the last state change (On/Off)."""
    nickname: str
    avatar: str
    has_set_location_info: bool
    region: Optional[str]
    latitude: Optional[float]
    longitude: Optional[float]
    time_diff: Optional[int]

    # Unique to this device
    default_states: DefaultPlugState
    """The default state of a device to be used when internet connectivity is lost after a power cut."""
    overcurrent_status: OvercurrentStatus
    overheat_status: Optional[OverheatStatus]
    power_protection_status: PowerProtectionStatus
    charging_status: ChargingStatus

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """

class DefaultPlugState:
    """Default Plug State."""

    type: DefaultStateType
    state: PlugState

class PlugState:
    """Plug State."""

    on: Optional[bool]



"""H100 Example"""

import asyncio
import os

from tapo import ApiClient
from tapo.requests import AlarmRingtone, AlarmVolume, AlarmDuration
from tapo.responses import KE100Result, S200BResult, T100Result, T110Result, T300Result, T31XResult


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")

    client = ApiClient(tapo_username, tapo_password)
    hub = await client.h100(ip_address)

    device_info = await hub.get_device_info()
    print(f"Device info: {device_info.to_dict()}")

    child_device_list = await hub.get_child_device_list()

    for child in child_device_list:
        if child is None:
            print("Found unsupported device.")
        elif isinstance(child, KE100Result):
            print(
                "Found KE100 child device with nickname: {}, id: {}, current temperature: {:.2f} {} and target temperature: {:.2f} {}.".format(
                    child.nickname,
                    child.device_id,
                    child.current_temperature,
                    child.temperature_unit,
                    child.target_temperature,
                    child.temperature_unit,
                )
            )
        elif isinstance(child, S200BResult):
            s200b = await hub.s200b(device_id=child.device_id)
            trigger_logs = await s200b.get_trigger_logs(5, 0)

            print(
                "Found S200B child device with nickname: {}, id: {}, last 5 trigger logs: {}.".format(
                    child.nickname,
                    child.device_id,
                    [log.to_dict() for log in trigger_logs.logs],
                )
            )
        elif isinstance(child, T100Result):
            t100 = await hub.t100(device_id=child.device_id)
            trigger_logs = await t100.get_trigger_logs(5, 0)

            print(
                "Found T100 child device with nickname: {}, id: {}, detected: {}, last 5 trigger logs: {}.".format(
                    child.nickname,
                    child.device_id,
                    child.detected,
                    [log.to_dict() for log in trigger_logs.logs],
                )
            )
        elif isinstance(child, T110Result):
            t110 = await hub.t110(device_id=child.device_id)
            trigger_logs = await t110.get_trigger_logs(5, 0)

            print(
                "Found T110 child device with nickname: {}, id: {}, open: {}, last 5 trigger logs: {}.".format(
                    child.nickname,
                    child.device_id,
                    child.open,
                    [log.to_dict() for log in trigger_logs.logs],
                )
            )
        elif isinstance(child, T300Result):
            t300 = await hub.t300(device_id=child.device_id)
            trigger_logs = await t300.get_trigger_logs(5, 0)

            print(
                "Found T300 child device with nickname: {}, id: {}, in_alarm: {}, water_leak_status: {}, last 5 trigger logs: {}.".format(
                    child.nickname,
                    child.device_id,
                    child.in_alarm,
                    child.water_leak_status,
                    [log.to_dict() for log in trigger_logs.logs],
                )
            )
        elif isinstance(child, T31XResult):
            t31x = await hub.t315(device_id=child.device_id)
            temperature_humidity_records = await t31x.get_temperature_humidity_records()

            print(
                "Found T31X child device with nickname: {}, id: {}, temperature: {:.2f} {}, humidity: {}%, earliest temperature and humidity record available: {}.".format(
                    child.nickname,
                    child.device_id,
                    child.current_temperature,
                    child.temperature_unit,
                    child.current_humidity,
                    (
                        temperature_humidity_records.records[0].to_dict()
                        if temperature_humidity_records.records
                        else None
                    ),
                )
            )

    print(f"Triggering the alarm ringtone 'Alarm 1' at a 'Low' volume for '3 Seconds'...")
    await hub.play_alarm(AlarmRingtone.Alarm1, AlarmVolume.Low, AlarmDuration.Seconds, seconds=3)

    device_info = await hub.get_device_info()
    print(f"Is device ringing?: {device_info.in_alarm}")

    print("Stopping the alarm after 1 Second...")
    await asyncio.sleep(1)
    await hub.stop_alarm()

    device_info = await hub.get_device_info()
    print(f"Is device ringing?: {device_info.in_alarm}")


if __name__ == "__main__":
    asyncio.run(main())



from datetime import datetime
from typing import List

from tapo.responses import HubResult, TemperatureUnit
from tapo.responses import TemperatureUnit

class T31XResult(HubResult):
    """Device info of Tapo T310 and T315 temperature and humidity sensors.

    Specific properties: `current_temperature`, `temperature_unit`,
    `current_temperature_exception`, `current_humidity`, `current_humidity_exception`,
    `report_interval`, `last_onboarding_timestamp`, `status_follow_edge`.
    """

    current_humidity_exception: int
    """
    This value will be `0` when the current humidity is within the comfort zone.
    When the current humidity value falls outside the comfort zone, this value
    will be the difference between the current humidity and the lower or upper bound of the comfort zone.
    """
    current_humidity: int
    current_temperature_exception: int
    """
    This value will be `0.0` when the current temperature is within the comfort zone.
    When the current temperature value falls outside the comfort zone, this value
    will be the difference between the current temperature and the lower or upper bound of the comfort zone.
    """
    current_temperature: int
    last_onboarding_timestamp: int
    report_interval: int
    """The time in seconds between each report."""
    status_follow_edge: bool
    temperature_unit: TemperatureUnit

class TemperatureHumidityRecords:
    """Temperature and Humidity records for the last 24 hours at 15 minute intervals."""

    datetime: datetime
    """The datetime in UTC of when this response was generated."""
    records: List[TemperatureHumidityRecord]
    temperature_unit: TemperatureUnit

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """

class TemperatureHumidityRecord:
    """Temperature and Humidity record as an average over a 15 minute interval."""

    datetime: datetime
    """Record's DateTime in UTC."""
    humidity_exception: int
    """This value will be `0` when the current humidity is within the comfort zone.
    When the current humidity value falls outside the comfort zone, this value
    will be the difference between the current humidity and the lower or upper bound of the comfort zone."""
    humidity: int
    temperature_exception: float
    """This value will be `0.0` when the current temperature is within the comfort zone.
    When the current temperature value falls outside the comfort zone, this value
    will be the difference between the current temperature and the lower or upper bound of the comfort zone."""
    temperature: float

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from tapo.responses import DeviceInfoGenericResult

class GenericDeviceHandler:
    """Handler for generic devices. It provides the functionality common to
    all Tapo [devices](https://www.tapo.com/en/).
    """

    def __init__(self, handler: object):
        """Private constructor.
        It should not be called from outside the tapo library.
        """

    async def refresh_session(self) -> None:
        """Refreshes the authentication session."""

    async def on(self) -> None:
        """Turns *on* the device."""

    async def off(self) -> None:
        """Turns *off* the device."""

    async def get_device_info(self) -> DeviceInfoGenericResult:
        """Returns *device info* as `DeviceInfoGenericResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `GenericDeviceHandler.get_device_info_json`.

        Returns:
            DeviceInfoGenericResult: Device info of a Generic Tapo device.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """



class CurrentPowerResult:
    """Contains the current power reading of the device."""

    current_power: int
    """Current power in Watts (W)."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from tapo.responses import UsageByPeriodResult

class DeviceUsageEnergyMonitoringResult:
    """Contains the time usage, the power consumption, and the energy savings of the device."""

    time_usage: UsageByPeriodResult
    """Time usage in minutes."""
    power_usage: UsageByPeriodResult
    """Power usage in Watt Hours (Wh)."""
    saved_power: UsageByPeriodResult
    """Saved power in Watt Hours (Wh)."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from enum import Enum
from tapo.responses.child_device_list_hub_result.hub_result import HubResult

class T300Result(HubResult):
    """Device info of Tapo T300 water sensor.

    Specific properties: `in_alarm`, `water_leak_status`, `report_interval`,
    `last_onboarding_timestamp`, `status_follow_edge`.
    """

    in_alarm: bool
    last_onboarding_timestamp: int
    report_interval: int
    """The time in seconds between each report."""
    status_follow_edge: bool
    water_leak_status: WaterLeakStatus

class WaterLeakStatus(str, Enum):
    """Water leak status."""

    Normal = "Normal"
    WaterDry = "WaterDry"
    WaterLeak = "WaterLeak"



"""L530, L535 and L630 Example"""

import asyncio
import os

from tapo import ApiClient
from tapo.requests import Color


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")

    client = ApiClient(tapo_username, tapo_password)
    device = await client.l530(ip_address)

    print("Turning device on...")
    await device.on()

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting the brightness to 30%...")
    await device.set_brightness(30)

    print("Setting the color to `Chocolate`...")
    await device.set_color(Color.Chocolate)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting the color to `Deep Sky Blue` using the `hue` and `saturation`...")
    await device.set_hue_saturation(195, 100)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting the color to `Incandescent` using the `color temperature`...")
    await device.set_color_temperature(2700)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Using the `set` API to set multiple properties in a single request...")
    await device.set().brightness(50).color(Color.HotPink).send(device)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Turning device off...")
    await device.off()

    device_info = await device.get_device_info()
    print(f"Device info: {device_info.to_dict()}")

    device_usage = await device.get_device_usage()
    print(f"Device usage: {device_usage.to_dict()}")


if __name__ == "__main__":
    asyncio.run(main())



"""KE100 TRV Example"""

import asyncio
import os

from tapo import ApiClient
from tapo.requests import TemperatureUnitKE100


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")
    # Name of the KE100 device.
    # Can be obtained from the Tapo App or by executing `get_child_device_component_list()` on the hub device.
    device_name = os.getenv("DEVICE_NAME")
    target_temperature = int(os.getenv("TARGET_TEMPERATURE"))

    client = ApiClient(tapo_username, tapo_password)
    hub = await client.h100(ip_address)

    # Get a handler for the child device
    device = await hub.ke100(nickname=device_name)

    # Get the device info of the child device
    device_info = await device.get_device_info()
    print(f"Device info: {device_info.to_dict()}")

    # Set target temperature.
    # KE100 currently only supports Celsius as temperature unit.
    print(f"Setting target temperature to {target_temperature} degrees Celsius...")
    await device.set_target_temperature(target_temperature, TemperatureUnitKE100.Celsius)

    # Get the device info of the child device
    device_info = await device.get_device_info()
    print(f"Device info: {device_info.to_dict()}")


if __name__ == "__main__":
    asyncio.run(main())



from typing import Optional

class UsageByPeriodResult:
    """Usage by period result for today, the past 7 days, and the past 30 days."""

    today: Optional[int]
    """Today."""
    past7: Optional[int]
    """Past 7 days."""
    past30: Optional[int]
    """Past 30 days."""

class DeviceUsageResult:
    """Contains the time usage."""

    time_usage: UsageByPeriodResult
    """Time usage in minutes."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from .api_client import *
from .color_light_handler import *
from .generic_device_handler import *
from .hub_handler import *
from .ke100_handler import *
from .light_handler import *
from .plug_energy_monitoring_handler import *
from .plug_handler import *
from .power_strip_handler import *
from .power_strip_plug_handler import *
from .requests import *
from .responses import *
from .rgb_light_strip_handler import *
from .rgbic_light_strip_handler import *
from .s200b_handler import *
from .t100_handler import *
from .t110_handler import *
from .t300_handler import *
from .t31x_handler import *



from tapo.responses.child_device_list_hub_result.status import Status

class HubResult:
    """Hub result. This is an abstract base class for all hub results."""

    at_low_battery: bool
    avatar: str
    bind_count: int
    category: str
    device_id: str
    fw_ver: str
    hw_id: str
    hw_ver: str
    jamming_rssi: int
    jamming_signal_level: int
    mac: str
    nickname: str
    oem_id: str
    parent_device_id: str
    region: str
    rssi: int
    signal_level: int
    specs: str
    status: Status
    type: str

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from tapo.requests import Color, ColorLightSetDeviceInfoParams
from tapo.responses import DeviceInfoRgbLightStripResult, DeviceUsageResult

class RgbLightStripHandler:
    """Handler for the [L900](https://www.tapo.com/en/search/?q=L900) devices."""

    def __init__(self, handler: object):
        """Private constructor.
        It should not be called from outside the tapo library.
        """

    async def refresh_session(self) -> None:
        """Refreshes the authentication session."""

    async def on(self) -> None:
        """Turns *on* the device."""

    async def off(self) -> None:
        """Turns *off* the device."""

    async def device_reset(self) -> None:
        """*Hardware resets* the device.

        Warning:
            This action will reset the device to its factory settings.
            The connection to the Wi-Fi network and the Tapo app will be lost,
            and the device will need to be reconfigured.

        This feature is especially useful when the device is difficult to access
        and requires reconfiguration.
        """

    async def get_device_info(self) -> DeviceInfoRgbLightStripResult:
        """Returns *device info* as `DeviceInfoRgbLightStripResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `RgbLightStripHandler.get_device_info_json`.

        Returns:
            DeviceInfoRgbLightStripResult: Device info of Tapo L900.
            Superset of `GenericDeviceInfoResult`.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_device_usage(self) -> DeviceUsageResult:
        """Returns *device usage* as `DeviceUsageResult`.

        Returns:
            DeviceUsageResult: Contains the time usage.
        """

    def set(self) -> ColorLightSetDeviceInfoParams:
        """Returns a `ColorLightSetDeviceInfoParams` builder that allows
        multiple properties to be set in a single request.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.

        Returns:
            ColorLightSetDeviceInfoParams: Builder that is used by the
            `RgbLightStripHandler.set` API to set multiple properties in a single request.
        """

    async def set_brightness(self, brightness: int) -> None:
        """Sets the *brightness* and turns *on* the device.

        Args:
            brightness (int): between 1 and 100
        """

    async def set_color(self, color: Color) -> None:
        """Sets the *color* and turns *on* the device.

        Args:
            color (Color): one of `tapo.Color` as defined in the Google Home app.
        """

    async def set_hue_saturation(self, hue: int, saturation: int) -> None:
        """Sets the *hue*, *saturation* and turns *on* the device.

        Args:
            hue (int): between 0 and 360
            saturation (int): between 1 and 100
        """

    async def set_color_temperature(self, color_temperature: int) -> None:
        """Sets the *color temperature* and turns *on* the device.

        Args:
            color_temperature (int): between 2500 and 6500
        """



from typing import Optional

class DeviceInfoPlugResult:
    """Device info of Tapo P100 and P105. Superset of `GenericDeviceInfoResult`."""

    device_id: str
    type: str
    model: str
    hw_id: str
    hw_ver: str
    fw_id: str
    fw_ver: str
    oem_id: str
    mac: str
    ip: str
    ssid: str
    signal_level: int
    rssi: int
    specs: str
    lang: str
    device_on: bool
    on_time: int
    """The time in seconds this device has been ON since the last state change (On/Off)."""
    nickname: str
    avatar: str
    has_set_location_info: bool
    region: Optional[str]
    latitude: Optional[float]
    longitude: Optional[float]
    time_diff: Optional[int]

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from enum import Enum

from tapo.responses.child_device_list_hub_result.hub_result import HubResult

class KE100Result(HubResult):
    """Device info of Tapo KE100 thermostatic radiator valve (TRV).

    Specific properties: `temperature_unit`, `current_temperature`, `target_temperature`,
    `min_control_temperature`, `max_control_temperature`, `temperature_offset`,
    `child_protection_on`, `frost_protection_on`, `location`.
    """

    child_protection_on: bool
    current_temperature: float
    frost_protection_on: bool
    location: str
    max_control_temperature: int
    min_control_temperature: int
    target_temperature: float
    temperature_offset: int
    temperature_unit: TemperatureUnitKE100

class TemperatureUnitKE100(str, Enum):
    """Temperature unit for KE100 devices.
    Currently *Celsius* is the only unit supported by KE100.
    """

    Celsius = "Celsius"



from datetime import datetime

class EnergyUsageResult:
    """Contains local time, current power and the energy usage and runtime for today and for the current month."""

    local_time: datetime
    """Local time of the device."""
    current_power: int
    """Current power in Milliwatts (mW)."""
    today_runtime: int
    """Today runtime in minutes."""
    today_energy: int
    """Today energy usage in Watt Hours (Wh)."""
    month_runtime: int
    """Current month runtime in minutes."""
    month_energy: int
    """Current month energy usage in Watt Hours (Wh)."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from datetime import datetime

from tapo.requests import EnergyDataInterval
from tapo.responses import (
    CurrentPowerResult,
    DeviceInfoPlugEnergyMonitoringResult,
    DeviceUsageEnergyMonitoringResult,
    EnergyDataResult,
    EnergyUsageResult,
)

class PlugEnergyMonitoringHandler:
    """Handler for the [P110](https://www.tapo.com/en/search/?q=P110) and
    [P115](https://www.tapo.com/en/search/?q=P115) devices.
    """

    def __init__(self, handler: object):
        """Private constructor.
        It should not be called from outside the tapo library.
        """

    async def refresh_session(self) -> None:
        """Refreshes the authentication session."""

    async def on(self) -> None:
        """Turns *on* the device."""

    async def off(self) -> None:
        """Turns *off* the device."""

    async def device_reset(self) -> None:
        """*Hardware resets* the device.

        Warning:
            This action will reset the device to its factory settings.
            The connection to the Wi-Fi network and the Tapo app will be lost,
            and the device will need to be reconfigured.

        This feature is especially useful when the device is difficult to access
        and requires reconfiguration.
        """

    async def get_device_info(self) -> DeviceInfoPlugEnergyMonitoringResult:
        """Returns *device info* as `DeviceInfoPlugEnergyMonitoringResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `PlugEnergyMonitoringHandler.get_device_info_json`.

        Returns:
            DeviceInfoPlugEnergyMonitoringResult: Device info of P110 and P115.
            Superset of `GenericDeviceInfoResult`.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_device_usage(self) -> DeviceUsageEnergyMonitoringResult:
        """Returns *device usage* as `DeviceUsageResult`.

        Returns:
            DeviceUsageEnergyMonitoringResult:
            Contains the time usage, the power consumption, and the energy savings of the device.
        """

    async def get_current_power(self) -> CurrentPowerResult:
        """Returns *current power* as `CurrentPowerResult`.

        Returns:
            CurrentPowerResult: Contains the current power reading of the device.
        """

    async def get_energy_usage(self) -> EnergyUsageResult:
        """Returns *energy usage* as `EnergyUsageResult`.

        Returns:
            EnergyUsageResult:
            Contains local time, current power and the energy usage and runtime for today and for the current month.
        """

    async def get_energy_data(
        self,
        interval: EnergyDataInterval,
        start_date: datetime,
        end_date: datetime = None,
    ) -> EnergyDataResult:
        """Returns *energy data* as `EnergyDataResult`.

        Returns:
            EnergyDataResult: Energy data for the requested `EnergyDataInterval`.
        """



from enum import Enum

class AlarmVolume(str, Enum):
    """The volume of the alarm.
    For the H100, this is a fixed list of volume levels."""

    Default = "Default"
    """Use the default volume for the hub."""

    Mute = "Mute"
    """Mute the audio output from the alarm.
    This causes the alarm to be shown as triggered in the Tapo App
    without an audible sound, and makes the `in_alarm` property
    in `DeviceInfoHubResult` return as `True`."""

    Low = "Low"
    """Lowest volume."""

    Normal = "Normal"
    """Normal volume. This is the default."""

    High = "High"
    """Highest volume."""

class AlarmRingtone(str, Enum):
    """The ringtone of a H100 alarm."""

    Alarm1 = "Alarm1"
    """Alarm 1"""

    Alarm2 = "Alarm2"
    """Alarm 2"""

    Alarm3 = "Alarm3"
    """Alarm 3"""

    Alarm4 = "Alarm4"
    """Alarm 4"""

    Alarm5 = "Alarm5"
    """Alarm 5"""

    Connection1 = "Connection1"
    """Connection 1"""

    Connection2 = "Connection2"
    """Connection 2"""

    DoorbellRing1 = "DoorbellRing1"
    """Doorbell Ring 1"""

    DoorbellRing2 = "DoorbellRing2"
    """Doorbell Ring 2"""

    DoorbellRing3 = "DoorbellRing3"
    """Doorbell Ring 3"""

    DoorbellRing4 = "DoorbellRing4"
    """Doorbell Ring 4"""

    DoorbellRing5 = "DoorbellRing5"
    """Doorbell Ring 5"""

    DoorbellRing6 = "DoorbellRing6"
    """Doorbell Ring 6"""

    DoorbellRing7 = "DoorbellRing7"
    """Doorbell Ring 7"""

    DoorbellRing8 = "DoorbellRing8"
    """Doorbell Ring 8"""

    DoorbellRing9 = "DoorbellRing9"
    """Doorbell Ring 9"""

    DoorbellRing10 = "DoorbellRing10"
    """Doorbell Ring 10"""

    DrippingTap = "DrippingTap"
    """Dripping Tap"""

    PhoneRing = "PhoneRing"
    """Phone Ring"""

class AlarmDuration(str, Enum):
    """Controls how long the alarm plays for."""

    Continuous = "Continuous"
    """Play the alarm continuously until stopped."""

    Once = "Once"
    """Play the alarm once.
    This is useful for previewing the audio.

    Limitations:

    The `in_alarm` field of `DeviceInfoHubResult` will not remain `True` for the
    duration of the audio track. Each audio track has a different runtime.

    Has no observable affect when used in conjunction with `AlarmVolume.Mute`."""

    Seconds = "Seconds"
    """Play the alarm a number of seconds."""



from datetime import datetime
from typing import List

class EnergyDataResult:
    """Energy data for the requested `EnergyDataInterval`."""

    local_time: datetime
    """Local time of the device."""

    data: List[int]
    """Energy data for the given `interval` in Watt Hours (Wh)."""

    start_timestamp: int
    """Start timestamp of the interval in milliseconds. This value is provided
    in the `get_energy_data` request and is passed through. Note that
    it may not align with the returned data if the method is used
    beyond its specified capabilities.
    """

    end_timestamp: int
    """End timestamp of the interval in milliseconds. This value is provided
    in the `get_energy_data` request and is passed through. Note that
    it may not align with the returned data for intervals other than hourly.
    """

    interval: int
    """Interval in minutes."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



from tapo.requests import TemperatureUnitKE100
from tapo.responses import KE100Result

class KE100Handler:
    """Handler for the [KE100](https://www.tp-link.com/en/search/?q=KE100) devices."""

    async def get_device_info(self) -> KE100Result:
        """Returns *device info* as `KE100Result`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `KE100Handler.get_device_info_json`.

        Returns:
            KE100Result: Device info of Tapo KE100 thermostatic radiator valve (TRV).
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def set_child_protection(self, on: bool) -> None:
        """Sets *child protection* on the device to *on* or *off*.

        Args:
            on (bool)
        """

    async def set_frost_protection(self, on: bool) -> None:
        """Sets *frost protection* on the device to *on* or *off*.

        Args:
            on (bool)
        """

    async def set_max_control_temperature(self, value: int, unit: TemperatureUnitKE100) -> None:
        """Sets the *maximum control temperature*.

        Args:
            value (int)
            unit (TemperatureUnitKE100)
        """

    async def set_min_control_temperature(self, value: int, unit: TemperatureUnitKE100) -> None:
        """Sets the *minimum control temperature*.

        Args:
            value (int)
            unit (TemperatureUnitKE100)
        """

    async def set_target_temperature(self, value: int, unit: TemperatureUnitKE100) -> None:
        """Sets the *target temperature*.

        Args:
            value (int): between `min_control_temperature` and `max_control_temperature`
            unit (TemperatureUnitKE100)
        """

    async def set_temperature_offset(self, value: int, unit: TemperatureUnitKE100) -> None:
        """Sets the *temperature offset*.

        Args:
            value (int): between -10 and 10
            unit (TemperatureUnitKE100)
        """



from enum import Enum
from typing import Tuple

class Color(str, Enum):
    """List of preset colors as defined in the Google Home app."""

    CoolWhite = "CoolWhite"
    Daylight = "Daylight"
    Ivory = "Ivory"
    WarmWhite = "WarmWhite"
    Incandescent = "Incandescent"
    Candlelight = "Candlelight"
    Snow = "Snow"
    GhostWhite = "GhostWhite"
    AliceBlue = "AliceBlue"
    LightGoldenrod = "LightGoldenrod"
    LemonChiffon = "LemonChiffon"
    AntiqueWhite = "AntiqueWhite"
    Gold = "Gold"
    Peru = "Peru"
    Chocolate = "Chocolate"
    SandyBrown = "SandyBrown"
    Coral = "Coral"
    Pumpkin = "Pumpkin"
    Tomato = "Tomato"
    Vermilion = "Vermilion"
    OrangeRed = "OrangeRed"
    Pink = "Pink"
    Crimson = "Crimson"
    DarkRed = "DarkRed"
    HotPink = "HotPink"
    Smitten = "Smitten"
    MediumPurple = "MediumPurple"
    BlueViolet = "BlueViolet"
    Indigo = "Indigo"
    LightSkyBlue = "LightSkyBlue"
    CornflowerBlue = "CornflowerBlue"
    Ultramarine = "Ultramarine"
    DeepSkyBlue = "DeepSkyBlue"
    Azure = "Azure"
    NavyBlue = "NavyBlue"
    LightTurquoise = "LightTurquoise"
    Aquamarine = "Aquamarine"
    Turquoise = "Turquoise"
    LightGreen = "LightGreen"
    Lime = "Lime"
    ForestGreen = "ForestGreen"

    def get_color_config(self) -> Tuple[int, int, int]:
        """Get the `hue`, `saturation`, and `color_temperature` of the color."""



from tapo.responses import T31XResult, TemperatureHumidityRecords

class T31XHandler:
    """Handler for the [T310](https://www.tapo.com/en/search/?q=T310)
    and [T315](https://www.tapo.com/en/search/?q=T315) devices."""

    async def get_device_info(self) -> T31XResult:
        """Returns *device info* as `T31XResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `T31XHandler.get_device_info_json`.

        Returns:
            T31XResult: Device info of Tapo T310 and T315 temperature and humidity sensors.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_temperature_humidity_records(self) -> TemperatureHumidityRecords:
        """Returns *temperature and humidity records* from the last 24 hours
        at 15 minute intervals as `TemperatureHumidityRecords`.

        Returns:
            TemperatureHumidityRecords: Temperature and Humidity records
            for the last 24 hours at 15 minute intervals.
        """



"""P110 and P115 Example"""

import asyncio
import os
from datetime import datetime

from tapo import ApiClient
from tapo.requests import EnergyDataInterval


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")

    client = ApiClient(tapo_username, tapo_password)
    device = await client.p110(ip_address)

    print("Turning device on...")
    await device.on()

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Turning device off...")
    await device.off()

    device_info = await device.get_device_info()
    print(f"Device info: {device_info.to_dict()}")

    device_usage = await device.get_device_usage()
    print(f"Device usage: {device_usage.to_dict()}")

    current_power = await device.get_current_power()
    print(f"Current power: {current_power.to_dict()}")

    energy_usage = await device.get_energy_usage()
    print(f"Energy usage: {energy_usage.to_dict()}")

    today = datetime.today()
    energy_data_hourly = await device.get_energy_data(EnergyDataInterval.Hourly, today)
    print(f"Energy data (hourly): {energy_data_hourly.to_dict()}")

    energy_data_daily = await device.get_energy_data(
        EnergyDataInterval.Daily,
        datetime(today.year, get_quarter_start_month(today), 1),
    )
    print(f"Energy data (daily): {energy_data_daily.to_dict()}")

    energy_data_monthly = await device.get_energy_data(
        EnergyDataInterval.Monthly,
        datetime(today.year, 1, 1),
    )
    print(f"Energy data (monthly): {energy_data_monthly.to_dict()}")


def get_quarter_start_month(today: datetime) -> int:
    return 3 * ((today.month - 1) // 3) + 1


if __name__ == "__main__":
    asyncio.run(main())



from tapo.responses import DeviceInfoLightResult, DeviceUsageResult

class LightHandler:
    """Handler for the [L510](https://www.tapo.com/en/search/?q=L510), [L520](https://www.tapo.com/en/search/?q=L520) and [L610](https://www.tapo.com/en/search/?q=L610) devices."""

    def __init__(self, handler: object):
        """Private constructor.
        It should not be called from outside the tapo library.
        """

    async def refresh_session(self) -> None:
        """Refreshes the authentication session."""

    async def on(self) -> None:
        """Turns *on* the device."""

    async def off(self) -> None:
        """Turns *off* the device."""

    async def device_reset(self) -> None:
        """*Hardware resets* the device.

        Warning:
            This action will reset the device to its factory settings.
            The connection to the Wi-Fi network and the Tapo app will be lost,
            and the device will need to be reconfigured.

        This feature is especially useful when the device is difficult to access
        and requires reconfiguration.
        """

    async def get_device_info(self) -> DeviceInfoLightResult:
        """Returns *device info* as `DeviceInfoLightResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `LightHandler.get_device_info_json`.

        Returns:
            DeviceInfoLightResult: Device info of Tapo L510, L520 and L610.
            Superset of `GenericDeviceInfoResult`.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_device_usage(self) -> DeviceUsageResult:
        """Returns *device usage* as `DeviceUsageResult`.

        Returns:
            DeviceUsageResult: Contains the time usage.
        """

    async def set_brightness(self, brightness: int) -> None:
        """Sets the *brightness* and turns *on* the device.

        Args:
            brightness (int): between 1 and 100
        """



from .color_light_result import *
from .default_state import *
from .generic_result import *
from .hub_result import *
from .light_result import *
from .plug_energy_monitoring_result import *
from .plug_result import *
from .power_status import *
from .power_strip_result import *
from .rgb_light_strip_result import *
from .rgbic_light_strip_result import *
from tapo.requests import LightingEffect as LightingEffect



"""P300 and P304 Example"""

import asyncio
import os

from tapo import ApiClient


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")

    client = ApiClient(tapo_username, tapo_password)
    power_strip = await client.p300(ip_address)

    device_info = await power_strip.get_device_info()
    print(f"Device info: {device_info.to_dict()}")

    child_device_list = await power_strip.get_child_device_list()

    for child in child_device_list:
        print(
            "Found plug with nickname: {}, id: {}, state: {}.".format(
                child.nickname,
                child.device_id,
                child.device_on,
            )
        )

        plug = await power_strip.plug(device_id=child.device_id)

        print("Turning device on...")
        await plug.on()

        print("Waiting 2 seconds...")
        await asyncio.sleep(2)

        print("Turning device off...")
        await plug.off()

        print("Waiting 2 seconds...")
        await asyncio.sleep(2)


if __name__ == "__main__":
    asyncio.run(main())



from enum import Enum
from typing import Optional

from tapo.responses.device_info_result.power_status import OverheatStatus

class PowerStripPlugResult:
    """P300 and P304 power strip child plugs."""

    auto_off_remain_time: int
    auto_off_status: AutoOffStatus
    avatar: str
    bind_count: int
    category: str
    device_id: str
    device_on: bool
    fw_id: str
    fw_ver: str
    has_set_location_info: bool
    hw_id: str
    hw_ver: str
    latitude: Optional[int]
    longitude: Optional[int]
    mac: str
    model: str
    nickname: str
    oem_id: str
    on_time: int
    """The time in seconds this device has been ON since the last state change (On/Off)."""
    original_device_id: str
    overheat_status: OverheatStatus
    position: int
    region: Optional[str]
    slot_number: int
    status_follow_edge: bool
    type: str

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """

class AutoOffStatus(str, Enum):
    On = "on"
    Off = "off"



from .hub_result import *
from .status import *
from .temperature_unit import *

from .ke100_result import *
from .s200b_result import *
from .t100_result import *
from .t110_result import *
from .t300_result import *
from .t31x_result import *



from tapo.responses.child_device_list_hub_result.hub_result import HubResult

class T100Result(HubResult):
    """Device info of Tapo T100 motion sensor.

    Specific properties: `detected`, `report_interval`,
    `last_onboarding_timestamp`, `status_follow_edge`.
    """

    detected: bool
    last_onboarding_timestamp: int
    report_interval: int
    """The time in seconds between each report."""
    status_follow_edge: bool



from .child_device_list_hub_result import *
from .child_device_list_power_strip_result import *
from .current_power_result import *
from .device_info_result import *
from .device_usage_energy_monitoring_result import *
from .device_usage_result import *
from .energy_data_result import *
from .energy_usage_result import *



from typing import List, Literal
from tapo.responses import T100Result

class T100Handler:
    """Handler for the [T100](https://www.tapo.com/en/search/?q=T100) devices."""

    async def get_device_info(self) -> T100Result:
        """Returns *device info* as `T100Result`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `T100Handler.get_device_info_json`.

        Returns:
            T100Result: Device info of Tapo T100 motion sensor.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_trigger_logs(self, page_size: int, start_id: int) -> TriggerLogsT100Result:
        """Returns a list of *trigger logs*.

        Args:
            page_size (int): the maximum number of log items to return
            start_id (int): the log item `id` from which to start returning results
                in reverse chronological order (newest first)

        Use a `start_id` of `0` to get the most recent X logs, where X is capped by `page_size`.

        Returns:
            TriggerLogsT100Result: Trigger logs result.
        """

class TriggerLogsT100Result:
    """Trigger logs result."""

    start_id: int
    """The `id` of the most recent log item that is returned."""
    sum: int
    """The total number of log items that the hub holds for this device."""
    logs: List[T100Log]
    """Log items in reverse chronological order (newest first)."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """

class T100Log:
    """T110 Log."""

    event: Literal["motion"]
    id: int
    timestamp: int

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



"""L920 and L930 Example"""

import asyncio
import os

from tapo import ApiClient
from tapo.requests import Color, LightingEffect, LightingEffectPreset, LightingEffectType


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")

    client = ApiClient(tapo_username, tapo_password)
    device = await client.l930(ip_address)

    print("Turning device on...")
    await device.on()

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting the brightness to 30%...")
    await device.set_brightness(30)

    print("Setting the color to `Chocolate`...")
    await device.set_color(Color.Chocolate)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting the color to `Deep Sky Blue` using the `hue` and `saturation`...")
    await device.set_hue_saturation(195, 100)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting the color to `Incandescent` using the `color temperature`...")
    await device.set_color_temperature(2700)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Using the `set` API to set multiple properties in a single request...")
    await device.set().brightness(50).color(Color.HotPink).send(device)

    print("Waiting 2 seconds...")
    await asyncio.sleep(2)

    print("Setting a preset Lighting effect...")
    await device.set_lighting_effect(LightingEffectPreset.BubblingCauldron)

    print("Waiting 10 seconds...")
    await asyncio.sleep(10)

    print("Setting a custom static Lighting effect...")
    custom_effect = (
        LightingEffect(
            "My Custom Static Effect", LightingEffectType.Static, True, True, 100, [(359, 85, 100)]
        )
        .with_expansion_strategy(1)
        .with_segments([0, 1, 2])
        .with_sequence([(359, 85, 100), (0, 0, 100), (236, 72, 100)])
    )
    await device.set_lighting_effect(custom_effect)

    print("Waiting 10 seconds...")
    await asyncio.sleep(10)

    print("Setting a custom sequence Lighting effect...")
    custom_effect = (
        LightingEffect(
            "My Custom Sequence Effect",
            LightingEffectType.Sequence,
            True,
            True,
            100,
            [(359, 85, 100)],
        )
        .with_expansion_strategy(1)
        .with_segments([0, 1, 2])
        .with_sequence([(359, 85, 100), (0, 0, 100), (236, 72, 100)])
        .with_direction(1)
        .with_duration(50)
    )
    await device.set_lighting_effect(custom_effect)

    print("Waiting 10 seconds...")
    await asyncio.sleep(10)

    print("Turning device off...")
    await device.off()

    device_info = await device.get_device_info()
    print(f"Device info: {device_info.to_dict()}")

    device_usage = await device.get_device_usage()
    print(f"Device usage: {device_usage.to_dict()}")


if __name__ == "__main__":
    asyncio.run(main())



from typing import List, Literal, Optional
from tapo.responses import S200BResult

class S200BHandler:
    """Handler for the [S200B](https://www.tapo.com/en/search/?q=S200B) devices."""

    async def get_device_info(self) -> S200BResult:
        """Returns *device info* as `S200BResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `S200BHandler.get_device_info_json`.

        Returns:
            S200BResult: Device info of Tapo S200B button switch.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_trigger_logs(self, page_size: int, start_id: int) -> TriggerLogsS200BResult:
        """Returns a list of *trigger logs*.

        Args:
            page_size (int): the maximum number of log items to return
            start_id (int): the log item `id` from which to start returning results
                in reverse chronological order (newest first)

        Use a `start_id` of `0` to get the most recent X logs, where X is capped by `page_size`.

        Returns:
            TriggerLogsS200BResult: Trigger logs result.
        """

class TriggerLogsS200BResult:
    """Trigger logs result."""

    start_id: int
    """The `id` of the most recent log item that is returned."""
    sum: int
    """The total number of log items that the hub holds for this device."""
    logs: List[S200BLog]
    """Log items in reverse chronological order (newest first)."""

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """

class S200BLog:
    """S200B Log."""

    event: Literal["rotation", "singleClick", "doubleClick", "lowBattery"]
    id: int
    timestamp: int
    params: Optional[S200BRotationParams]

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """

class S200BRotationParams:
    """S200B Rotation log params."""

    rotation_degrees: int

    def to_dict(self) -> dict:
        """Gets all the properties of this result as a dictionary.

        Returns:
            dict: The result as a dictionary.
        """



"""Tapo API Client.

Tested with light bulbs (L510, L520, L530, L535, L610, L630), light strips (L900, L920, L930), plugs (P100, P105, P110, P115), 
power strips (P300, P304), hubs (H100), switches (S200B) and sensors (KE100, T100, T110, T300, T310, T315).

Example:
    ```python
    import asyncio
    from tapo import ApiClient


    async def main():
        client = ApiClient("tapo-username@example.com", "tapo-password")
        device = await client.l530("192.168.1.100")

        await device.on()

    if __name__ == "__main__":
        asyncio.run(main())
    ```

See [more examples](https://github.com/mihai-dinculescu/tapo/tree/main/tapo-py/examples).
"""

from .color_light_handler import ColorLightHandler
from .generic_device_handler import GenericDeviceHandler
from .hub_handler import HubHandler
from .light_handler import LightHandler
from .plug_energy_monitoring_handler import PlugEnergyMonitoringHandler
from .plug_handler import PlugHandler
from .power_strip_handler import PowerStripHandler
from .rgb_light_strip_handler import RgbLightStripHandler
from .rgbic_light_strip_handler import RgbicLightStripHandler

class ApiClient:
    """Tapo API Client.

    Tested with light bulbs (L510, L520, L530, L535, L610, L630), light strips (L900, L920, L930), plugs (P100, P105, P110, P115),
    power strips (P300, P304), hubs (H100), switches (S200B) and sensors (KE100, T100, T110, T300, T310, T315).

    Example:
        ```python
        import asyncio
        from tapo import ApiClient


        async def main():
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l530("192.168.1.100")

            await device.on()

        if __name__ == "__main__":
            asyncio.run(main())
        ```

    See [more examples](https://github.com/mihai-dinculescu/tapo/tree/main/tapo-py/examples).
    """

    def __init__(self, tapo_username: str, tapo_password: str, timeout_s: int = 30) -> None:
        """Returns a new instance of `ApiClient`.

        Args:
            tapo_username (str): The Tapo username.
            tapo_password (str): The Tapo password.
            timeout_s (int): The connection timeout in seconds. The default value is 30 seconds.

        Returns:
            ApiClient: Tapo API Client.

        Example:
            ```python
            import asyncio
            from tapo import ApiClient


            async def main():
                client = ApiClient("tapo-username@example.com", "tapo-password")
                device = await client.l530("192.168.1.100")

                await device.on()

            if __name__ == "__main__":
                asyncio.run(main())
            ```

        See [more examples](https://github.com/mihai-dinculescu/tapo/tree/main/tapo-py/examples).
        """

    async def generic_device(self, ip_address: str) -> GenericDeviceHandler:
        """Specializes the given `ApiClient` into an authenticated `GenericDeviceHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            GenericDeviceHandler: Handler for generic devices. It provides the
            functionality common to all Tapo [devices](https://www.tapo.com/en/).

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.generic_device("192.168.1.100")

            await device.on()
            ```
        """

    async def l510(self, ip_address: str) -> LightHandler:
        """Specializes the given `ApiClient` into an authenticated `LightHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            LightHandler: Handler for the [L510](https://www.tapo.com/en/search/?q=L510),
            [L520](https://www.tapo.com/en/search/?q=L520) and [L610](https://www.tapo.com/en/search/?q=L610) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l510("192.168.1.100")

            await device.on()
            ```
        """

    async def l520(self, ip_address: str) -> LightHandler:
        """Specializes the given `ApiClient` into an authenticated `LightHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            LightHandler: Handler for the [L510](https://www.tapo.com/en/search/?q=L510),
            [L520](https://www.tapo.com/en/search/?q=L520) and [L610](https://www.tapo.com/en/search/?q=L610) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l520("192.168.1.100")

            await device.on()
            ```
        """

    async def l530(self, ip_address: str) -> ColorLightHandler:
        """Specializes the given `ApiClient` into an authenticated `ColorLightHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            ColorLightHandler: Handler for the [L530](https://www.tapo.com/en/search/?q=L530),
            [L535](https://www.tapo.com/en/search/?q=L535) and [L630](https://www.tapo.com/en/search/?q=L630) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l530("192.168.1.100")

            await device.on()
            ```
        """

    async def l535(self, ip_address: str) -> ColorLightHandler:
        """Specializes the given `ApiClient` into an authenticated `ColorLightHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            ColorLightHandler: Handler for the [L530](https://www.tapo.com/en/search/?q=L530),
            [L535](https://www.tapo.com/en/search/?q=L535) and [L630](https://www.tapo.com/en/search/?q=L630) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l535("192.168.1.100")

            await device.on()
            ```
        """

    async def l610(self, ip_address: str) -> LightHandler:
        """Specializes the given `ApiClient` into an authenticated `LightHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            LightHandler: Handler for the [L510](https://www.tapo.com/en/search/?q=L510),
            [L520](https://www.tapo.com/en/search/?q=L520) and [L610](https://www.tapo.com/en/search/?q=L610) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l610("192.168.1.100")

            await device.on()
            ```
        """

    async def l630(self, ip_address: str) -> ColorLightHandler:
        """Specializes the given `ApiClient` into an authenticated `ColorLightHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            ColorLightHandler: Handler for the [L530](https://www.tapo.com/en/search/?q=L530),
            [L630](https://www.tapo.com/en/search/?q=L630) and [L900](https://www.tapo.com/en/search/?q=L900) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l630("192.168.1.100")

            await device.on()
            ```
        """

    async def l900(self, ip_address: str) -> RgbLightStripHandler:
        """Specializes the given `ApiClient` into an authenticated `RgbLightStripHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            RgbLightStripHandler: Handler for the [L900](https://www.tapo.com/en/search/?q=L900) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l900("192.168.1.100")

            await device.on()
            ```
        """

    async def l920(self, ip_address: str) -> RgbicLightStripHandler:
        """Specializes the given `ApiClient` into an authenticated `RgbicLightStripHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            RgbicLightStripHandler: Handler for the [L920](https://www.tapo.com/en/search/?q=L920) and
            [L930](https://www.tapo.com/en/search/?q=L930) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l920("192.168.1.100")

            await device.on()
            ```
        """

    async def l930(self, ip_address: str) -> RgbicLightStripHandler:
        """Specializes the given `ApiClient` into an authenticated `RgbicLightStripHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            RgbicLightStripHandler: Handler for the [L920](https://www.tapo.com/en/search/?q=L920) and
            [L930](https://www.tapo.com/en/search/?q=L930) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.l930("192.168.1.100")

            await device.on()
            ```
        """

    async def p100(self, ip_address: str) -> PlugHandler:
        """Specializes the given `ApiClient` into an authenticated `PlugHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            PlugHandler: Handler for the [P100](https://www.tapo.com/en/search/?q=P100) and
            [P105](https://www.tapo.com/en/search/?q=P105) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.p100("192.168.1.100")

            await device.on()
            ```
        """

    async def p105(self, ip_address: str) -> PlugHandler:
        """Specializes the given `ApiClient` into an authenticated `PlugHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            PlugHandler: Handler for the [P100](https://www.tapo.com/en/search/?q=P100) and
            [P105](https://www.tapo.com/en/search/?q=P105) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.p105("192.168.1.100")

            await device.on()
            ```
        """

    async def p110(self, ip_address: str) -> PlugEnergyMonitoringHandler:
        """Specializes the given `ApiClient` into an authenticated `PlugEnergyMonitoringHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            PlugEnergyMonitoringHandler: Handler for the [P110](https://www.tapo.com/en/search/?q=P110) and
            [P115](https://www.tapo.com/en/search/?q=P115) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.p110("192.168.1.100")

            await device.on()
            ```
        """

    async def p115(self, ip_address: str) -> PlugEnergyMonitoringHandler:
        """Specializes the given `ApiClient` into an authenticated `PlugEnergyMonitoringHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            PlugEnergyMonitoringHandler: Handler for the [P110](https://www.tapo.com/en/search/?q=P110) and
            [P115](https://www.tapo.com/en/search/?q=P115) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            device = await client.p115("192.168.1.100")

            await device.on()
            ```
        """

    async def p300(self, ip_address: str) -> PowerStripHandler:
        """Specializes the given `ApiClient` into an authenticated `PowerStripHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            PowerStripHandler: Handler for the [P300](https://www.tapo.com/en/search/?q=P300) and
            [P304](https://www.tp-link.com/uk/search/?q=P304) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            power_strip = await client.p300("192.168.1.100")

            child_device_list = await power_strip.get_child_device_list()
            print(f"Child device list: {child_device_list.to_dict()}")
            ```
        """

    async def p304(self, ip_address: str) -> PowerStripHandler:
        """Specializes the given `ApiClient` into an authenticated `PowerStripHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            PowerStripHandler: Handler for the [P300](https://www.tapo.com/en/search/?q=P300) and
            [P304](https://www.tp-link.com/uk/search/?q=P304) devices.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            power_strip = await client.p300("192.168.1.100")

            child_device_list = await power_strip.get_child_device_list()
            print(f"Child device list: {child_device_list.to_dict()}")
            ```
        """

    async def h100(self, ip_address: str) -> HubHandler:
        """Specializes the given `ApiClient` into an authenticated `HubHandler`.

        Args:
            ip_address (str): The IP address of the device

        Returns:
            HubHandler: Handler for the [H100](https://www.tapo.com/en/search/?q=H100) hubs.

        Example:
            ```python
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            child_device_list = await hub.get_child_device_list()
            print(f"Child device list: {child_device_list.to_dict()}")
            ```
        """



from typing import List, Optional

from tapo import PowerStripPlugHandler
from tapo.responses import DeviceInfoPowerStripResult, PowerStripPlugResult

class PowerStripHandler:
    """Handler for the [P300](https://www.tapo.com/en/search/?q=P300) and
    [P304](https://www.tp-link.com/uk/search/?q=P304) devices.
    """

    def __init__(self, handler: object):
        """Private constructor.
        It should not be called from outside the tapo library.
        """

    async def refresh_session(self) -> None:
        """Refreshes the authentication session."""

    async def get_device_info(self) -> DeviceInfoPowerStripResult:
        """Returns *device info* as `DeviceInfoPowerStripResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `HubHandler.get_device_info_json`.

        Returns:
            DeviceInfoPowerStripResult: Device info of Tapo P300 and P304. Superset of `DeviceInfoGenericResult`.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_child_device_list(
        self,
    ) -> List[PowerStripPlugResult]:
        """Returns *child device list* as `List[PowerStripPlugResult]`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `PowerStripHandler.get_child_device_list_json`.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_child_device_list_json(self) -> dict:
        """Returns *child device list* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_child_device_component_list_json(self) -> dict:
        """Returns *child device component list* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def plug(
        self,
        device_id: Optional[str] = None,
        nickname: Optional[str] = None,
        position: Optional[int] = None,
    ) -> PowerStripPlugHandler:
        """Returns a `PowerStripPlugHandler` for the device matching the provided `device_id`, `nickname`, or `position`.

        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device
            position (Optional[str]): The Position of the device

        Returns:
            PowerStripPlugHandler: Handler for the [P300](https://www.tapo.com/en/search/?q=P300) and
            [P304](https://www.tp-link.com/uk/search/?q=P304) child plugs.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            power_strip = await client.p300("192.168.1.100")

            # Get a handler for the child device
            device = await power_strip.plug(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """



from typing import Union

from tapo.color_light_handler import ColorLightHandler
from tapo.requests import Color
from tapo.rgb_light_strip_handler import RgbLightStripHandler

class ColorLightSetDeviceInfoParams:
    """Builder that is used by the `ColorLightHandler.set` API to set
    multiple properties in a single request.
    """

    def on(self) -> ColorLightSetDeviceInfoParams:
        """Turns *on* the device.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.
        """

    def off(self) -> ColorLightSetDeviceInfoParams:
        """Turns *off* the device.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.
        """

    def brightness(self, brightness: int) -> ColorLightSetDeviceInfoParams:
        """Sets the *brightness*.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.
        The device will also be turned *on*, unless `ColorLightSetDeviceInfoParams.off` is called.

        Args:
            brightness (int): between 1 and 100
        """

    def color(self, color: Color) -> ColorLightSetDeviceInfoParams:
        """Sets the *color*.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.
        The device will also be turned *on*, unless `ColorLightSetDeviceInfoParams.off` is called.

        Args:
            color (Color): one of `tapo.Color` as defined in the Google Home app.
        """

    def hue_saturation(self, hue: int, saturation: int) -> ColorLightSetDeviceInfoParams:
        """Sets the *hue* and *saturation*.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.
        The device will also be turned *on*, unless `ColorLightSetDeviceInfoParams.off` is called.

        Args:
            hue (int): between 0 and 360
            saturation (int): between 1 and 100
        """

    def color_temperature(self, color_temperature: int) -> ColorLightSetDeviceInfoParams:
        """
        Sets the *color temperature*.
        `ColorLightSetDeviceInfoParams.send` must be called at the end to apply the changes.
        The device will also be turned *on*, unless `ColorLightSetDeviceInfoParams.off` is called.

        Args:
            color_temperature (int): between 2500 and 6500
        """

    async def send(self, handler: Union[ColorLightHandler, RgbLightStripHandler]) -> None:
        """Performs a request to apply the changes to the device.

        Args:
            handler (`ColorLightHandler` | `RgbLightStripHandler`)
        """



"""Toggle Generic Device Example"""

import asyncio
import os

from tapo import ApiClient


async def main():
    tapo_username = os.getenv("TAPO_USERNAME")
    tapo_password = os.getenv("TAPO_PASSWORD")
    ip_address = os.getenv("IP_ADDRESS")

    client = ApiClient(tapo_username, tapo_password)
    device = await client.generic_device(ip_address)

    device_info = await device.get_device_info()

    if device_info.device_on == True:
        print("Device is on. Turning it off...")
        await device.off()
    elif device_info.device_on == False:
        print("Device is off. Turning it on...")
        await device.on()
    else:
        print("This device does not support on/off functionality.")


if __name__ == "__main__":
    asyncio.run(main())



from enum import Enum
from typing import List, Optional, Tuple

class LightingEffectType(str, Enum):
    Sequence = "Sequence"
    Random = "Random"
    Pulse = "Pulse"
    Static = "Static"

class LightingEffect:
    brightness: int
    is_custom: bool
    display_colors: List[Tuple[int, int, int]]
    """The colors that will be displayed in the Tapo app."""
    enabled: bool
    id: str
    name: str
    type: str
    backgrounds: Optional[List[Tuple[int, int, int]]]
    brightness_range: Optional[List[Tuple[int, int]]]
    direction: Optional[int]
    duration: Optional[int]
    expansion_strategy: Optional[int]
    fade_off: Optional[int]
    hue_range: Optional[List[Tuple[int, int]]]
    init_states: Optional[List[Tuple[int, int, int]]]
    random_seed: Optional[int]
    repeat_times: Optional[int]
    run_time: Optional[int]
    saturation_range: Optional[List[Tuple[int, int]]]
    segment_length: Optional[int]
    segments: Optional[List[int]]
    sequence: Optional[List[Tuple[int, int, int]]]
    spread: Optional[int]
    transition: Optional[int]
    transition_range: Optional[List[Tuple[int, int]]]
    transition_sequence: Optional[List[int]]

    def __init__(
        self,
        name: str,
        type: LightingEffectType,
        is_custom: bool,
        enabled: bool,
        brightness: int,
        display_colors: List[Tuple[int, int, int]],
    ) -> None: ...
    def with_brightness(self, brightness: int) -> LightingEffect: ...
    def with_is_custom(self, is_custom: bool) -> LightingEffect: ...
    def with_display_colors(self, display_colors: List[Tuple[int, int, int]]) -> LightingEffect: ...
    def with_enabled(self, enabled: bool) -> LightingEffect: ...
    def with_id(self, id: str) -> LightingEffect: ...
    def with_name(self, name: str) -> LightingEffect: ...
    def with_type(self, type: LightingEffectType) -> LightingEffect: ...
    def with_backgrounds(self, backgrounds: List[Tuple[int, int, int]]) -> LightingEffect: ...
    def with_brightness_range(self, brightness_range: Tuple[int, int]) -> LightingEffect: ...
    def with_direction(self, direction: int) -> LightingEffect: ...
    def with_duration(self, duration: int) -> LightingEffect: ...
    def with_expansion_strategy(self, expansion_strategy: int) -> LightingEffect: ...
    def with_fade_off(self, fade_off: int) -> LightingEffect: ...
    def with_hue_range(self, hue_range: Tuple[int, int]) -> LightingEffect: ...
    def with_init_states(self, init_states: List[Tuple[int, int, int]]) -> LightingEffect: ...
    def with_random_seed(self, random_seed: int) -> LightingEffect: ...
    def with_repeat_times(self, repeat_times: int) -> LightingEffect: ...
    def with_run_time(self, run_time: int) -> LightingEffect: ...
    def with_saturation_range(self, saturation_range: Tuple[int, int]) -> LightingEffect: ...
    def with_segment_length(self, segment_length: int) -> LightingEffect: ...
    def with_segments(self, segments: List[int]) -> LightingEffect: ...
    def with_sequence(self, sequence: List[Tuple[int, int, int]]) -> LightingEffect: ...
    def with_spread(self, spread: int) -> LightingEffect: ...
    def with_transition(self, transition: int) -> LightingEffect: ...
    def with_transition_range(self, transition_range: Tuple[int, int]) -> LightingEffect: ...
    def with_transition_sequence(self, transition_sequence: List[int]) -> LightingEffect: ...

class LightingEffectPreset(str, Enum):
    Aurora = "Aurora"
    BubblingCauldron = "BubblingCauldron"
    CandyCane = "CandyCane"
    Christmas = "Christmas"
    Flicker = "Flicker"
    GrandmasChristmasLights = "GrandmasChristmasLights"
    Hanukkah = "Hanukkah"
    HauntedMansion = "HauntedMansion"
    Icicle = "Icicle"
    Lightning = "Lightning"
    Ocean = "Ocean"
    Rainbow = "Rainbow"
    Raindrop = "Raindrop"
    Spring = "Spring"
    Sunrise = "Sunrise"
    Sunset = "Sunset"
    Valentines = "Valentines"



from typing import List, Optional, Union

from tapo import KE100Handler, S200BHandler, T100Handler, T110Handler, T300Handler, T31XHandler
from tapo.requests.play_alarm import AlarmDuration, AlarmRingtone, AlarmVolume
from tapo.responses import (
    DeviceInfoHubResult,
    KE100Result,
    S200BResult,
    T100Result,
    T110Result,
    T300Result,
    T31XResult,
)

class HubHandler:
    """Handler for the [H100](https://www.tapo.com/en/search/?q=H100) hubs."""

    def __init__(self, handler: object):
        """Private constructor.
        It should not be called from outside the tapo library.
        """

    async def refresh_session(self) -> None:
        """Refreshes the authentication session."""

    async def get_device_info(self) -> DeviceInfoHubResult:
        """Returns *device info* as `DeviceInfoHubResult`.
        It is not guaranteed to contain all the properties returned from the Tapo API.
        If the deserialization fails, or if a property that you care about it's not present,
        try `HubHandler.get_device_info_json`.

        Returns:
            DeviceInfoHubResult: Device info of Tapo H100.
            Superset of `GenericDeviceInfoResult`.
        """

    async def get_device_info_json(self) -> dict:
        """Returns *device info* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_child_device_list(
        self,
    ) -> List[
        Union[KE100Result, S200BResult, T100Result, T110Result, T300Result, T31XResult, None]
    ]:
        """Returns *child device list* as `List[KE100Result | S200BResult | T100Result | T110Result | T300Result | T31XResult | None]`.
        It is not guaranteed to contain all the properties returned from the Tapo API
        or to support all the possible devices connected to the hub.
        If the deserialization fails, or if a property that you care about it's not present,
        try `HubHandler.get_child_device_list_json`.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_child_device_list_json(self, start_index: int) -> dict:
        """Returns *child device list* as json.
        It contains all the properties returned from the Tapo API.

        Args:
            start_index (int): the index to start fetching the child device list.
            It should be `0` for the first page, `10` for the second, and so on.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_child_device_component_list_json(self) -> dict:
        """Returns *child device component list* as json.
        It contains all the properties returned from the Tapo API.

        Returns:
            dict: Device info as a dictionary.
        """

    async def get_supported_ringtone_list() -> List[str]:
        """Returns a list of ringtones (alarm types) supported by the hub.
        Used for debugging only.

        Returns:
            List[str]: List of the ringtones supported by the hub.
        """

    async def play_alarm(
        self,
        ringtone: AlarmRingtone,
        volume: AlarmVolume,
        duration: AlarmDuration,
        seconds: Optional[int] = None,
    ) -> None:
        """Start playing the hub alarm.

        Args:
            ringtone (AlarmRingtone): The ringtone of a H100 alarm.
            volume (AlarmVolume): The volume of the alarm.
            duration (AlarmDuration): Controls how long the alarm plays for.
            seconds (Optional[int]): Play the alarm a number of seconds. Required if `duration` is `AlarmDuration.Seconds`.
        """

    async def stop_alarm(self) -> None:
        """Stop playing the hub alarm, if it's currently playing."""

    async def ke100(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> KE100Handler:
        """Returns a `KE100Handler` for the device matching the provided `device_id` or `nickname`.

        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            KE100Handler: Handler for the [KE100](https://www.tp-link.com/en/search/?q=KE100) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.ke100(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """

    async def s200b(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> S200BHandler:
        """Returns a `S200BHandler` for the device matching the provided `device_id` or `nickname`.

        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            S200BHandler: Handler for the [S200B](https://www.tapo.com/en/search/?q=S200B) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.s200b(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """

    async def t100(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> T100Handler:
        """Returns a `T100Handler` for the device matching the provided `device_id` or `nickname`.

        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            T100Handler: Handler for the [T100](https://www.tapo.com/en/search/?q=T100) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.t100(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """

    async def t110(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> T110Handler:
        """Returns a `T110Handler` for the device matching the provided `device_id` or `nickname`.

        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            T110Handler: Handler for the [T110](https://www.tapo.com/en/search/?q=T110) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.t110(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """

    async def t300(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> T300Handler:
        """Returns a `T300Handler` for the device matching the provided `device_id` or `nickname`.

        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            T300Handler: Handler for the [T300](https://www.tapo.com/en/search/?q=T300) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.t300(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """

    async def t310(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> T31XHandler:
        """Returns a `T31XHandler` for the device matching the provided `device_id` or `nickname`.
        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            T31XHandler: Handler for the [T310](https://www.tapo.com/en/search/?q=T310)
            and [T315](https://www.tapo.com/en/search/?q=T315) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.t310(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """

    async def t315(
        self, device_id: Optional[str] = None, nickname: Optional[str] = None
    ) -> T31XHandler:
        """Returns a `T31XHandler` for the device matching the provided `device_id` or `nickname`.
        Args:
            device_id (Optional[str]): The Device ID of the device
            nickname (Optional[str]): The Nickname of the device

        Returns:
            T31XHandler: Handler for the [T310](https://www.tapo.com/en/search/?q=T310)
            and [T315](https://www.tapo.com/en/search/?q=T315) devices.

        Example:
            ```python
            # Connect to the hub
            client = ApiClient("tapo-username@example.com", "tapo-password")
            hub = await client.h100("192.168.1.100")

            # Get a handler for the child device
            device = await hub.t315(device_id="0000000000000000000000000000000000000000")

            # Get the device info of the child device
            device_info = await device.get_device_info()
            print(f"Device info: {device_info.to_dict()}")
            ```
        """



from tapo.responses.child_device_list_hub_result.hub_result import HubResult

class T110Result(HubResult):
    """Device info of Tapo T110 contact sensor.

    Specific properties: `open`, `report_interval`,
    `last_onboarding_timestamp`,`status_follow_edge`.
    """

    last_onboarding_timestamp: int
    open: bool
    report_interval: int
    """The time in seconds between each report."""
    status_follow_edge: bool
